"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsUploadViewModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "file_id": "str",
        "file_expiration": "datetime",
        "file_properties": "dict(str, object)",
    }

    attribute_map = {
        "file_id": "FileId",
        "file_expiration": "FileExpiration",
        "file_properties": "FileProperties",
    }

    def __init__(
        self,
        file_id=None,
        file_expiration=None,
        file_properties=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsUploadViewModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._file_id = None
        self._file_expiration = None
        self._file_properties = None
        self.discriminator = None

        if file_id is not None:
            self.file_id = file_id
        if file_expiration is not None:
            self.file_expiration = file_expiration
        if file_properties is not None:
            self.file_properties = file_properties

    @property
    def file_id(self):
        # type: () -> str
        """Gets the file_id of this UserSiteCommonModelsUploadViewModel.


        :return: The file_id of this UserSiteCommonModelsUploadViewModel.
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this UserSiteCommonModelsUploadViewModel.


        :param file_id: The file_id of this UserSiteCommonModelsUploadViewModel.
        :type: str
        """

        self._file_id = file_id

    @property
    def file_expiration(self):
        # type: () -> datetime
        """Gets the file_expiration of this UserSiteCommonModelsUploadViewModel.


        :return: The file_expiration of this UserSiteCommonModelsUploadViewModel.
        :rtype: datetime
        """
        return self._file_expiration

    @file_expiration.setter
    def file_expiration(self, file_expiration):
        """Sets the file_expiration of this UserSiteCommonModelsUploadViewModel.


        :param file_expiration: The file_expiration of this UserSiteCommonModelsUploadViewModel.
        :type: datetime
        """

        self._file_expiration = file_expiration

    @property
    def file_properties(self):
        # type: () -> dict(str, object)
        """Gets the file_properties of this UserSiteCommonModelsUploadViewModel.


        :return: The file_properties of this UserSiteCommonModelsUploadViewModel.
        :rtype: dict(str, object)
        """
        return self._file_properties

    @file_properties.setter
    def file_properties(self, file_properties):
        """Sets the file_properties of this UserSiteCommonModelsUploadViewModel.


        :param file_properties: The file_properties of this UserSiteCommonModelsUploadViewModel.
        :type: dict(str, object)
        """

        self._file_properties = file_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsUploadViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsUploadViewModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsUploadViewModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsSubscriptionInfoModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "is_valid": "bool",
        "is_trial": "bool",
        "hide_counters": "bool",
        "offering_type": "str",
        "expiration_date": "datetime",
        "removal_date": "datetime",
        "subscription_id": "str",
        "tenant_id": "str",
        "total_seats": "int",
        "taken_seats": "int",
        "full_report_for_trial_enaled": "bool",
        "purchase_supplier": "str",
        "max_users": "int",
    }

    attribute_map = {
        "is_valid": "IsValid",
        "is_trial": "IsTrial",
        "hide_counters": "HideCounters",
        "offering_type": "OfferingType",
        "expiration_date": "ExpirationDate",
        "removal_date": "RemovalDate",
        "subscription_id": "SubscriptionId",
        "tenant_id": "TenantId",
        "total_seats": "TotalSeats",
        "taken_seats": "TakenSeats",
        "full_report_for_trial_enaled": "FullReportForTrialEnaled",
        "purchase_supplier": "PurchaseSupplier",
        "max_users": "MaxUsers",
    }

    def __init__(
        self,
        is_valid=None,
        is_trial=None,
        hide_counters=None,
        offering_type=None,
        expiration_date=None,
        removal_date=None,
        subscription_id=None,
        tenant_id=None,
        total_seats=None,
        taken_seats=None,
        full_report_for_trial_enaled=None,
        purchase_supplier=None,
        max_users=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsSubscriptionInfoModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._is_valid = None
        self._is_trial = None
        self._hide_counters = None
        self._offering_type = None
        self._expiration_date = None
        self._removal_date = None
        self._subscription_id = None
        self._tenant_id = None
        self._total_seats = None
        self._taken_seats = None
        self._full_report_for_trial_enaled = None
        self._purchase_supplier = None
        self._max_users = None
        self.discriminator = None

        if is_valid is not None:
            self.is_valid = is_valid
        if is_trial is not None:
            self.is_trial = is_trial
        if hide_counters is not None:
            self.hide_counters = hide_counters
        if offering_type is not None:
            self.offering_type = offering_type
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if removal_date is not None:
            self.removal_date = removal_date
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if total_seats is not None:
            self.total_seats = total_seats
        if taken_seats is not None:
            self.taken_seats = taken_seats
        if full_report_for_trial_enaled is not None:
            self.full_report_for_trial_enaled = full_report_for_trial_enaled
        if purchase_supplier is not None:
            self.purchase_supplier = purchase_supplier
        if max_users is not None:
            self.max_users = max_users

    @property
    def is_valid(self):
        # type: () -> bool
        """Gets the is_valid of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The is_valid of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this UserSiteCommonModelsSubscriptionInfoModel.


        :param is_valid: The is_valid of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def is_trial(self):
        # type: () -> bool
        """Gets the is_trial of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The is_trial of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: bool
        """
        return self._is_trial

    @is_trial.setter
    def is_trial(self, is_trial):
        """Sets the is_trial of this UserSiteCommonModelsSubscriptionInfoModel.


        :param is_trial: The is_trial of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: bool
        """

        self._is_trial = is_trial

    @property
    def hide_counters(self):
        # type: () -> bool
        """Gets the hide_counters of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The hide_counters of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: bool
        """
        return self._hide_counters

    @hide_counters.setter
    def hide_counters(self, hide_counters):
        """Sets the hide_counters of this UserSiteCommonModelsSubscriptionInfoModel.


        :param hide_counters: The hide_counters of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: bool
        """

        self._hide_counters = hide_counters

    @property
    def offering_type(self):
        # type: () -> str
        """Gets the offering_type of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The offering_type of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: str
        """
        return self._offering_type

    @offering_type.setter
    def offering_type(self, offering_type):
        """Sets the offering_type of this UserSiteCommonModelsSubscriptionInfoModel.


        :param offering_type: The offering_type of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: str
        """

        self._offering_type = offering_type

    @property
    def expiration_date(self):
        # type: () -> datetime
        """Gets the expiration_date of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The expiration_date of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this UserSiteCommonModelsSubscriptionInfoModel.


        :param expiration_date: The expiration_date of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: datetime
        """

        self._expiration_date = expiration_date

    @property
    def removal_date(self):
        # type: () -> datetime
        """Gets the removal_date of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The removal_date of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: datetime
        """
        return self._removal_date

    @removal_date.setter
    def removal_date(self, removal_date):
        """Sets the removal_date of this UserSiteCommonModelsSubscriptionInfoModel.


        :param removal_date: The removal_date of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: datetime
        """

        self._removal_date = removal_date

    @property
    def subscription_id(self):
        # type: () -> str
        """Gets the subscription_id of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The subscription_id of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this UserSiteCommonModelsSubscriptionInfoModel.


        :param subscription_id: The subscription_id of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def tenant_id(self):
        # type: () -> str
        """Gets the tenant_id of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The tenant_id of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this UserSiteCommonModelsSubscriptionInfoModel.


        :param tenant_id: The tenant_id of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def total_seats(self):
        # type: () -> int
        """Gets the total_seats of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The total_seats of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: int
        """
        return self._total_seats

    @total_seats.setter
    def total_seats(self, total_seats):
        """Sets the total_seats of this UserSiteCommonModelsSubscriptionInfoModel.


        :param total_seats: The total_seats of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: int
        """

        self._total_seats = total_seats

    @property
    def taken_seats(self):
        # type: () -> int
        """Gets the taken_seats of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The taken_seats of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: int
        """
        return self._taken_seats

    @taken_seats.setter
    def taken_seats(self, taken_seats):
        """Sets the taken_seats of this UserSiteCommonModelsSubscriptionInfoModel.


        :param taken_seats: The taken_seats of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: int
        """

        self._taken_seats = taken_seats

    @property
    def full_report_for_trial_enaled(self):
        # type: () -> bool
        """Gets the full_report_for_trial_enaled of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The full_report_for_trial_enaled of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: bool
        """
        return self._full_report_for_trial_enaled

    @full_report_for_trial_enaled.setter
    def full_report_for_trial_enaled(self, full_report_for_trial_enaled):
        """Sets the full_report_for_trial_enaled of this UserSiteCommonModelsSubscriptionInfoModel.


        :param full_report_for_trial_enaled: The full_report_for_trial_enaled of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: bool
        """

        self._full_report_for_trial_enaled = full_report_for_trial_enaled

    @property
    def purchase_supplier(self):
        # type: () -> str
        """Gets the purchase_supplier of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The purchase_supplier of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: str
        """
        return self._purchase_supplier

    @purchase_supplier.setter
    def purchase_supplier(self, purchase_supplier):
        """Sets the purchase_supplier of this UserSiteCommonModelsSubscriptionInfoModel.


        :param purchase_supplier: The purchase_supplier of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: str
        """

        self._purchase_supplier = purchase_supplier

    @property
    def max_users(self):
        # type: () -> int
        """Gets the max_users of this UserSiteCommonModelsSubscriptionInfoModel.


        :return: The max_users of this UserSiteCommonModelsSubscriptionInfoModel.
        :rtype: int
        """
        return self._max_users

    @max_users.setter
    def max_users(self, max_users):
        """Sets the max_users of this UserSiteCommonModelsSubscriptionInfoModel.


        :param max_users: The max_users of this UserSiteCommonModelsSubscriptionInfoModel.
        :type: int
        """

        self._max_users = max_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsSubscriptionInfoModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsSubscriptionInfoModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsSubscriptionInfoModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsFixGroup:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "app_id": "str",
        "fix_group_type": "str",
        "subject": "str",
        "fix_location_entity_type": "str",
        "severity": "str",
        "severity_value": "int",
        "n_issues": "int",
        "n_open_issues": "int",
        "issue_type_id": "str",
        "issue_type": "str",
        "date_created": "datetime",
        "last_updated": "datetime",
        "last_found": "datetime",
        "status": "str",
        "sticky_status": "bool",
        "file": "str",
        "line": "int",
        "hash_version": "int",
        "hash": "str",
        "notes": "str",
    }

    attribute_map = {
        "id": "Id",
        "app_id": "AppId",
        "fix_group_type": "FixGroupType",
        "subject": "Subject",
        "fix_location_entity_type": "FixLocationEntityType",
        "severity": "Severity",
        "severity_value": "SeverityValue",
        "n_issues": "NIssues",
        "n_open_issues": "NOpenIssues",
        "issue_type_id": "IssueTypeId",
        "issue_type": "IssueType",
        "date_created": "DateCreated",
        "last_updated": "LastUpdated",
        "last_found": "LastFound",
        "status": "Status",
        "sticky_status": "StickyStatus",
        "file": "File",
        "line": "Line",
        "hash_version": "HashVersion",
        "hash": "Hash",
        "notes": "Notes",
    }

    def __init__(
        self,
        id=None,
        app_id=None,
        fix_group_type=None,
        subject=None,
        fix_location_entity_type=None,
        severity=None,
        severity_value=None,
        n_issues=None,
        n_open_issues=None,
        issue_type_id=None,
        issue_type=None,
        date_created=None,
        last_updated=None,
        last_found=None,
        status=None,
        sticky_status=None,
        file=None,
        line=None,
        hash_version=None,
        hash=None,
        notes=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsFixGroup - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._app_id = None
        self._fix_group_type = None
        self._subject = None
        self._fix_location_entity_type = None
        self._severity = None
        self._severity_value = None
        self._n_issues = None
        self._n_open_issues = None
        self._issue_type_id = None
        self._issue_type = None
        self._date_created = None
        self._last_updated = None
        self._last_found = None
        self._status = None
        self._sticky_status = None
        self._file = None
        self._line = None
        self._hash_version = None
        self._hash = None
        self._notes = None
        self.discriminator = None

        self.id = id
        self.app_id = app_id
        self.fix_group_type = fix_group_type
        self.subject = subject
        self.fix_location_entity_type = fix_location_entity_type
        if severity is not None:
            self.severity = severity
        if severity_value is not None:
            self.severity_value = severity_value
        self.n_issues = n_issues
        self.n_open_issues = n_open_issues
        self.issue_type_id = issue_type_id
        self.issue_type = issue_type
        self.date_created = date_created
        if last_updated is not None:
            self.last_updated = last_updated
        if last_found is not None:
            self.last_found = last_found
        if status is not None:
            self.status = status
        self.sticky_status = sticky_status
        if file is not None:
            self.file = file
        if line is not None:
            self.line = line
        self.hash_version = hash_version
        self.hash = hash
        if notes is not None:
            self.notes = notes

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsFixGroup.


        :return: The id of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsFixGroup.


        :param id: The id of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def app_id(self):
        # type: () -> str
        """Gets the app_id of this UserSiteCommonModelsFixGroup.


        :return: The app_id of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this UserSiteCommonModelsFixGroup.


        :param app_id: The app_id of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and app_id is None:
            raise ValueError("Invalid value for `app_id`, must not be `None`")

        self._app_id = app_id

    @property
    def fix_group_type(self):
        # type: () -> str
        """Gets the fix_group_type of this UserSiteCommonModelsFixGroup.


        :return: The fix_group_type of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._fix_group_type

    @fix_group_type.setter
    def fix_group_type(self, fix_group_type):
        """Sets the fix_group_type of this UserSiteCommonModelsFixGroup.


        :param fix_group_type: The fix_group_type of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and fix_group_type is None:
            raise ValueError("Invalid value for `fix_group_type`, must not be `None`")
        allowed_values = ["OpenSourceLib", "FixLocation", "Api"]
        if self._configuration.client_side_validation and fix_group_type not in allowed_values:
            raise ValueError(
                "Invalid value for `fix_group_type` ({}), must be one of {}".format(
                    fix_group_type, allowed_values
                )
            )

        self._fix_group_type = fix_group_type

    @property
    def subject(self):
        # type: () -> str
        """Gets the subject of this UserSiteCommonModelsFixGroup.


        :return: The subject of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this UserSiteCommonModelsFixGroup.


        :param subject: The subject of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")

        self._subject = subject

    @property
    def fix_location_entity_type(self):
        # type: () -> str
        """Gets the fix_location_entity_type of this UserSiteCommonModelsFixGroup.


        :return: The fix_location_entity_type of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._fix_location_entity_type

    @fix_location_entity_type.setter
    def fix_location_entity_type(self, fix_location_entity_type):
        """Sets the fix_location_entity_type of this UserSiteCommonModelsFixGroup.


        :param fix_location_entity_type: The fix_location_entity_type of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and fix_location_entity_type is None:
            raise ValueError("Invalid value for `fix_location_entity_type`, must not be `None`")
        allowed_values = ["None", "ImplementationOf", "UsageOf"]
        if (
            self._configuration.client_side_validation
            and fix_location_entity_type not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `fix_location_entity_type` ({}), must be one of {}".format(
                    fix_location_entity_type, allowed_values
                )
            )

        self._fix_location_entity_type = fix_location_entity_type

    @property
    def severity(self):
        # type: () -> str
        """Gets the severity of this UserSiteCommonModelsFixGroup.


        :return: The severity of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this UserSiteCommonModelsFixGroup.


        :param severity: The severity of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        allowed_values = [
            "Undetermined",
            "Informational",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and severity not in allowed_values:
            raise ValueError(
                "Invalid value for `severity` ({}), must be one of {}".format(
                    severity, allowed_values
                )
            )

        self._severity = severity

    @property
    def severity_value(self):
        # type: () -> int
        """Gets the severity_value of this UserSiteCommonModelsFixGroup.


        :return: The severity_value of this UserSiteCommonModelsFixGroup.
        :rtype: int
        """
        return self._severity_value

    @severity_value.setter
    def severity_value(self, severity_value):
        """Sets the severity_value of this UserSiteCommonModelsFixGroup.


        :param severity_value: The severity_value of this UserSiteCommonModelsFixGroup.
        :type: int
        """

        self._severity_value = severity_value

    @property
    def n_issues(self):
        # type: () -> int
        """Gets the n_issues of this UserSiteCommonModelsFixGroup.


        :return: The n_issues of this UserSiteCommonModelsFixGroup.
        :rtype: int
        """
        return self._n_issues

    @n_issues.setter
    def n_issues(self, n_issues):
        """Sets the n_issues of this UserSiteCommonModelsFixGroup.


        :param n_issues: The n_issues of this UserSiteCommonModelsFixGroup.
        :type: int
        """
        if self._configuration.client_side_validation and n_issues is None:
            raise ValueError("Invalid value for `n_issues`, must not be `None`")

        self._n_issues = n_issues

    @property
    def n_open_issues(self):
        # type: () -> int
        """Gets the n_open_issues of this UserSiteCommonModelsFixGroup.


        :return: The n_open_issues of this UserSiteCommonModelsFixGroup.
        :rtype: int
        """
        return self._n_open_issues

    @n_open_issues.setter
    def n_open_issues(self, n_open_issues):
        """Sets the n_open_issues of this UserSiteCommonModelsFixGroup.


        :param n_open_issues: The n_open_issues of this UserSiteCommonModelsFixGroup.
        :type: int
        """
        if self._configuration.client_side_validation and n_open_issues is None:
            raise ValueError("Invalid value for `n_open_issues`, must not be `None`")

        self._n_open_issues = n_open_issues

    @property
    def issue_type_id(self):
        # type: () -> str
        """Gets the issue_type_id of this UserSiteCommonModelsFixGroup.


        :return: The issue_type_id of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._issue_type_id

    @issue_type_id.setter
    def issue_type_id(self, issue_type_id):
        """Sets the issue_type_id of this UserSiteCommonModelsFixGroup.


        :param issue_type_id: The issue_type_id of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and issue_type_id is None:
            raise ValueError("Invalid value for `issue_type_id`, must not be `None`")

        self._issue_type_id = issue_type_id

    @property
    def issue_type(self):
        # type: () -> str
        """Gets the issue_type of this UserSiteCommonModelsFixGroup.


        :return: The issue_type of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._issue_type

    @issue_type.setter
    def issue_type(self, issue_type):
        """Sets the issue_type of this UserSiteCommonModelsFixGroup.


        :param issue_type: The issue_type of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and issue_type is None:
            raise ValueError("Invalid value for `issue_type`, must not be `None`")

        self._issue_type = issue_type

    @property
    def date_created(self):
        # type: () -> datetime
        """Gets the date_created of this UserSiteCommonModelsFixGroup.


        :return: The date_created of this UserSiteCommonModelsFixGroup.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this UserSiteCommonModelsFixGroup.


        :param date_created: The date_created of this UserSiteCommonModelsFixGroup.
        :type: datetime
        """
        if self._configuration.client_side_validation and date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")

        self._date_created = date_created

    @property
    def last_updated(self):
        # type: () -> datetime
        """Gets the last_updated of this UserSiteCommonModelsFixGroup.


        :return: The last_updated of this UserSiteCommonModelsFixGroup.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this UserSiteCommonModelsFixGroup.


        :param last_updated: The last_updated of this UserSiteCommonModelsFixGroup.
        :type: datetime
        """

        self._last_updated = last_updated

    @property
    def last_found(self):
        # type: () -> datetime
        """Gets the last_found of this UserSiteCommonModelsFixGroup.


        :return: The last_found of this UserSiteCommonModelsFixGroup.
        :rtype: datetime
        """
        return self._last_found

    @last_found.setter
    def last_found(self, last_found):
        """Sets the last_found of this UserSiteCommonModelsFixGroup.


        :param last_found: The last_found of this UserSiteCommonModelsFixGroup.
        :type: datetime
        """

        self._last_found = last_found

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this UserSiteCommonModelsFixGroup.


        :return: The status of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UserSiteCommonModelsFixGroup.


        :param status: The status of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        allowed_values = [
            "Open",
            "InProgress",
            "Reopened",
            "Noise",
            "Passed",
            "Fixed",
            "New",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def sticky_status(self):
        # type: () -> bool
        """Gets the sticky_status of this UserSiteCommonModelsFixGroup.


        :return: The sticky_status of this UserSiteCommonModelsFixGroup.
        :rtype: bool
        """
        return self._sticky_status

    @sticky_status.setter
    def sticky_status(self, sticky_status):
        """Sets the sticky_status of this UserSiteCommonModelsFixGroup.


        :param sticky_status: The sticky_status of this UserSiteCommonModelsFixGroup.
        :type: bool
        """
        if self._configuration.client_side_validation and sticky_status is None:
            raise ValueError("Invalid value for `sticky_status`, must not be `None`")

        self._sticky_status = sticky_status

    @property
    def file(self):
        # type: () -> str
        """Gets the file of this UserSiteCommonModelsFixGroup.


        :return: The file of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this UserSiteCommonModelsFixGroup.


        :param file: The file of this UserSiteCommonModelsFixGroup.
        :type: str
        """

        self._file = file

    @property
    def line(self):
        # type: () -> int
        """Gets the line of this UserSiteCommonModelsFixGroup.


        :return: The line of this UserSiteCommonModelsFixGroup.
        :rtype: int
        """
        return self._line

    @line.setter
    def line(self, line):
        """Sets the line of this UserSiteCommonModelsFixGroup.


        :param line: The line of this UserSiteCommonModelsFixGroup.
        :type: int
        """

        self._line = line

    @property
    def hash_version(self):
        # type: () -> int
        """Gets the hash_version of this UserSiteCommonModelsFixGroup.


        :return: The hash_version of this UserSiteCommonModelsFixGroup.
        :rtype: int
        """
        return self._hash_version

    @hash_version.setter
    def hash_version(self, hash_version):
        """Sets the hash_version of this UserSiteCommonModelsFixGroup.


        :param hash_version: The hash_version of this UserSiteCommonModelsFixGroup.
        :type: int
        """
        if self._configuration.client_side_validation and hash_version is None:
            raise ValueError("Invalid value for `hash_version`, must not be `None`")

        self._hash_version = hash_version

    @property
    def hash(self):
        # type: () -> str
        """Gets the hash of this UserSiteCommonModelsFixGroup.


        :return: The hash of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this UserSiteCommonModelsFixGroup.


        :param hash: The hash of this UserSiteCommonModelsFixGroup.
        :type: str
        """
        if self._configuration.client_side_validation and hash is None:
            raise ValueError("Invalid value for `hash`, must not be `None`")

        self._hash = hash

    @property
    def notes(self):
        # type: () -> str
        """Gets the notes of this UserSiteCommonModelsFixGroup.


        :return: The notes of this UserSiteCommonModelsFixGroup.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this UserSiteCommonModelsFixGroup.


        :param notes: The notes of this UserSiteCommonModelsFixGroup.
        :type: str
        """

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsFixGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsFixGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsFixGroup):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class MicrosoftDataEdmIEdmSchemaElement:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"schema_element_kind": "str", "namespace": "str", "name": "str"}

    attribute_map = {
        "schema_element_kind": "SchemaElementKind",
        "namespace": "Namespace",
        "name": "Name",
    }

    def __init__(self, schema_element_kind=None, namespace=None, name=None, _configuration=None):
        """MicrosoftDataEdmIEdmSchemaElement - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._schema_element_kind = None
        self._namespace = None
        self._name = None
        self.discriminator = None

        if schema_element_kind is not None:
            self.schema_element_kind = schema_element_kind
        if namespace is not None:
            self.namespace = namespace
        if name is not None:
            self.name = name

    @property
    def schema_element_kind(self):
        # type: () -> str
        """Gets the schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._schema_element_kind

    @schema_element_kind.setter
    def schema_element_kind(self, schema_element_kind):
        """Sets the schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.


        :param schema_element_kind: The schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """
        allowed_values = [
            "None",
            "TypeDefinition",
            "Function",
            "ValueTerm",
            "EntityContainer",
        ]
        if self._configuration.client_side_validation and schema_element_kind not in allowed_values:
            raise ValueError(
                "Invalid value for `schema_element_kind` ({}), must be one of {}".format(
                    schema_element_kind, allowed_values
                )
            )

        self._schema_element_kind = schema_element_kind

    @property
    def namespace(self):
        # type: () -> str
        """Gets the namespace of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The namespace of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this MicrosoftDataEdmIEdmSchemaElement.


        :param namespace: The namespace of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """

        self._namespace = namespace

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The name of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MicrosoftDataEdmIEdmSchemaElement.


        :param name: The name of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(MicrosoftDataEdmIEdmSchemaElement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicrosoftDataEdmIEdmSchemaElement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MicrosoftDataEdmIEdmSchemaElement):
            return True

        return self.to_dict() != other.to_dict()
